function opts = getCALMSROptimizationParams

    % Underlying iteration scheme (Gauss-Newton ('GN') or 
    % Levenberg-Marquardt ('LM') iterations).
    opts.algorithm = 'LM';
    
    % Image prior (Total variation ('TV') or bilateral TV ('BTV')).
    opts.imagePrior = 'BTV';
    
    % Window size (radius) for BTV prior.
    opts.btvWindowSize = 1;
    
    % Weighting factor for BTV prior.
    opts.btvWeightingFactor = 0.5;
    
    % Regularization weight for the high-resolution image (for TV or BTV).
    opts.imageRegularizationWeight = 1e-2;
    
    % Regularization weight to regularize motion parameter updates 
    % (see He, Y. et al, A Nonlinear Least Square Technique for Simultaneous 
    % Image Registration and Super-Resolution. IEEE TIP, 16(11), 28302841.
    % Can be set to zero if no regularization should be applied to the
    % motion parameters.
    opts.motionRegularizationWeight = 0;
    
    % Search range for Levenberg-Marquardt damping parameter.
    opts.dampingParameterSearchRange = logspace(-4, 4, 5);
    
    % Maximum number of Levenberg-Marquardt / Gauss Newton iterations.
    opts.maxLMIter = 20;
    
    % Maximum number of conjugate gradients iterations used in the inner
    % optimization loop.
    opts.maxCGIter = 50;
    
    % Termination tolerance for max(x(t) - x(t-1)) for the estimate of the
    % high-resolution image (should be approx. 1e-3).
    opts.terminationTol = 1e-3;
        
    % The weighting function that is used to determine the observation
    % confidence weights. This function needs to be defined as a struct P 
    % with the following fields:
    %   - P.function is a function handle to weighting function to compute
    %     the confidence weights based on the residual error. The residual
    %     errors for the different frames need to be stored as a cell
    %     array.
    %   - P.parameters are additional parameters that are passed to the
    %     function P.function.
    opts.observationWeightingFunction = estimateHuberObservationWeights;
    
    % The weighting function that is used to determine the adaptive prior
    % weights. This function needs to be defined as a struct P with the 
    % following fields:
    %   - P.function is a function handle to weighting function to compute
    %     the prior weights based on a given image in a certain transform
    %     domain.
    %   - P.parameters are additional parameters that are passed to the
    %     function P.function.
    opts.priorWeightingFunction = estimateWBTVPriorWeights;