% Setup Matlab path.
addpath('../../');
setupSRToolbox;

% Path to the Image Alignment toolbox (see http://iatool.net/)
addpath('IAT_v0.9.1');
iat_setup;

%% Load low-resolution frames
load('disk.mat');

% Setup super-resolution model parameters
model = SRModel;
model.magFactor = 3;
model.psfWidth = 0.4;
transform = 'euclidean';
refFrame = 1;

% Motion estimation for individual low-resolution frames.
if isempty(model.motionParams)
    % Set parameters for ECC registration algorithm.
    eccParams.iterations = 30;
    eccParams.levels = 2;
    eccParams.transform = transform;
    for m = 1:size(LRImages, 3)
        
        if m == refFrame
            motionParams{m} = eye(3,3);
            continue;
        end
        
        % Pair-wise registration of the current frame to the reference.
        I = LRImages(:,:,refFrame);
        H = iat_ecc(LRImages(:,:,m), I, eccParams);
        
        % Assemble motion parameter structure.
        if strcmp(transform, 'translation')
            H = [1 0 H(1); 0 1 H(2); 0 0 1];
        else
            if size(H, 1) < 3
                H = [H; 0 0 1];
            end
        end
        motionParams{m} = inv(H);
    end
    model.motionParams = motionParams;
end

%% Super-resolution via confidence-aware Levenberg-Marquardt optimization

% Optimization parameters.
calmsrParams = getCALMSROptimizationParams;
calmsrParams.maxLMIter = 25;
calmsrParams.maxCGIter = 50;
calmsrParams.imageRegularizationWeight = 1e-2;
calmsrParams.algorithm = 'LM';

% Run super-resolution algorithm.
[SR_calmsr, report] = superresolve(LRImages, model, 'calmsr', calmsrParams);

figure;
imshow(report.SR{1});
title('Initial guess');
figure;
imshow(SR_calmsr);
title('CALM super-resolution');